add method

bool add(
  1. T element
)

Adds element to the set.

If the element already exists, the set remains unchanged. Returns true if the element was added, false if it already existed.

Implementation

bool add(T element) => _elements.add(element);