emptySet method
Creates an empty set.
This is a convenience method for creating empty sets.
Implementation
CustomSet<T> emptySet() => CustomSet.empty();
Creates an empty set.
This is a convenience method for creating empty sets.
CustomSet<T> emptySet() => CustomSet.empty();