isNotEmpty property
bool
get
isNotEmpty
Returns true if the set contains at least one element.
Implementation
bool get isNotEmpty => _elements.isNotEmpty;
Returns true if the set contains at least one element.
bool get isNotEmpty => _elements.isNotEmpty;