isProperSupersetOf method

bool isProperSupersetOf(
  1. CustomSet<T> other
)

Checks if this set is a proper superset of other.

Notation: A ⊃ B

Returns true if this set is a superset of other and not equal to other.

Implementation

bool isProperSupersetOf(CustomSet<T> other) => other.isProperSubsetOf(this);