isSupersetOf method

bool isSupersetOf(
  1. CustomSet<T> other
)

Checks if this set is a superset of other.

Notation: A ⊇ B

Returns true if every element of other is also in this set.

Implementation

bool isSupersetOf(CustomSet<T> other) => other.isSubsetOf(this);