remove method
Removes element from the set.
Returns true if the element was removed, false if it was not found.
Implementation
bool remove(T element) => _elements.remove(element);
Removes element from the set.
Returns true if the element was removed, false if it was not found.
bool remove(T element) => _elements.remove(element);