toSet method
Converts this multiset to a standard set.
All duplicate elements are removed, keeping only unique elements.
Implementation
CustomSet<T> toSet() => CustomSet(_elements.keys);
Converts this multiset to a standard set.
All duplicate elements are removed, keeping only unique elements.
CustomSet<T> toSet() => CustomSet(_elements.keys);