AdvancedSetOperations class
Provides advanced set operations beyond the basic operations.
This class includes operations such as Cartesian product, power set, partition validation, and the inclusion-exclusion principle.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
cartesianProduct<
T, U> (CustomSet< T> a, CustomSet<U> b) → CustomSet<(T, U)> - Returns the Cartesian product of two sets.
-
cartesianProductN<
T> (List< CustomSet< sets) → CustomSet<T> >List< T> > - Returns the Cartesian product of n sets.
-
inclusionExclusion2<
T> (CustomSet< T> a, CustomSet<T> b) → int - Applies the inclusion-exclusion principle for two sets.
-
inclusionExclusion3<
T> (CustomSet< T> a, CustomSet<T> b, CustomSet<T> c) → int - Applies the inclusion-exclusion principle for three sets.
-
isPartition<
T> (CustomSet< CustomSet< partitions, CustomSet<T> >T> original) → bool - Checks if a collection of sets forms a valid partition of the original set.