SetLaws class
Provides verification methods for standard set theory laws.
These laws are fundamental identities in set algebra that can be used to prove set equivalences and simplify set expressions.
Each method returns true if the law holds for the given sets.
Constructors
- SetLaws()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
absorptionIntersection<
T> (CustomSet< T> a, CustomSet<T> b) → bool - Verifies the Absorption Law for Intersection.
-
absorptionUnion<
T> (CustomSet< T> a, CustomSet<T> b) → bool - Verifies the Absorption Law for Union.
-
associativeIntersection<
T> (CustomSet< T> a, CustomSet<T> b, CustomSet<T> c) → bool - Verifies the Associative Law for Intersection.
-
associativeUnion<
T> (CustomSet< T> a, CustomSet<T> b, CustomSet<T> c) → bool - Verifies the Associative Law for Union.
-
commutativeIntersection<
T> (CustomSet< T> a, CustomSet<T> b) → bool - Verifies the Commutative Law for Intersection.
-
commutativeUnion<
T> (CustomSet< T> a, CustomSet<T> b) → bool - Verifies the Commutative Law for Union.
-
complementIntersection<
T> (CustomSet< T> a, CustomSet<T> universal) → bool - Verifies the Complement Law for Intersection.
-
complementUnion<
T> (CustomSet< T> a, CustomSet<T> universal) → bool - Verifies the Complement Law for Union.
-
deMorganIntersection<
T> (CustomSet< T> a, CustomSet<T> b, CustomSet<T> universal) → bool - Verifies De Morgan's Law for Intersection.
-
deMorganUnion<
T> (CustomSet< T> a, CustomSet<T> b, CustomSet<T> universal) → bool - Verifies De Morgan's Law for Union.
-
distributiveIntersection<
T> (CustomSet< T> a, CustomSet<T> b, CustomSet<T> c) → bool - Verifies the Distributive Law for Intersection over Union.
-
distributiveUnion<
T> (CustomSet< T> a, CustomSet<T> b, CustomSet<T> c) → bool - Verifies the Distributive Law for Union over Intersection.
-
idempotentIntersection<
T> (CustomSet< T> a) → bool - Verifies the Idempotent Law for Intersection.
-
idempotentUnion<
T> (CustomSet< T> a) → bool - Verifies the Idempotent Law for Union.
-
identityIntersection<
T> (CustomSet< T> a, CustomSet<T> universal) → bool - Verifies the Identity Law for Intersection.
-
identityUnion<
T> (CustomSet< T> a) → bool - Verifies the Identity Law for Union.
-
involution<
T> (CustomSet< T> a, CustomSet<T> universal) → bool - Verifies the Involution Law.
-
lawOne<
T> (CustomSet< T> universal) → bool - Verifies the Law 0/1 for Universal Set Complement.
-
lawZero<
T> (CustomSet< T> universal) → bool - Verifies the Law 0/1 for Empty Set Complement.
-
nullIntersection<
T> (CustomSet< T> a) → bool - Verifies the Null/Domination Law for Intersection.
-
nullUnion<
T> (CustomSet< T> a, CustomSet<T> universal) → bool - Verifies the Null/Domination Law for Union.