SetOperations class
Provides basic set operations as defined in set theory.
This class contains static methods for fundamental set operations including intersection, union, complement, difference, and symmetric difference.
All operations follow standard mathematical notation and properties.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
complement<
T> (CustomSet< T> a, CustomSet<T> universal) → CustomSet<T> - Returns the complement of a set with respect to a universal set.
-
difference<
T> (CustomSet< T> a, CustomSet<T> b) → CustomSet<T> - Returns the difference of two sets.
-
intersection<
T> (CustomSet< T> a, CustomSet<T> b) → CustomSet<T> - Returns the intersection of two sets.
-
symmetricDifference<
T> (CustomSet< T> a, CustomSet<T> b) → CustomSet<T> - Returns the symmetric difference of two sets.
-
symmetricDifferenceAlt<
T> (CustomSet< T> a, CustomSet<T> b) → CustomSet<T> - Returns the symmetric difference using alternative formula.
-
union<
T> (CustomSet< T> a, CustomSet<T> b) → CustomSet<T> - Returns the union of two sets.